from datetime import timezone, datetime
from fastapi import APIRouter, Request, Depends, Security
from sqlalchemy.orm import Session
from api.db.database import get_db
from api.v1.routes.task import user_task_statistics
from api.v1.services.user import user_service
from api.v1.services.task import task_service
from fastapi.responses import HTMLResponse, RedirectResponse
from api.utils.config import templates_env

from fastapi_pagination import Params

profileview = APIRouter(prefix="/profile", tags=["User external Views and UI"])

Title = "User Profile"

@profileview.get("/{username}", response_class=HTMLResponse)
def dashboard(username: str,
            request: Request, 
            db: Session = Depends(get_db),
            params: Params=Depends(),
              ):
    
    user = user_service.fetch_by_username(db, username = username)
    joined = user.created_at.strftime("%Y-%m-%d")
    """ wallet = user_service.fetch_user_walletbalance(user_id, db=db) """
    task_stats = user_task_statistics(db=db, user_id=user.id)
    alltasks = task_service.task_query_profile(db=db, user_id=user.id, params=params)
    
    recent_tasks = sorted(alltasks.get('data'), 
                          key=lambda x: x["created_at"], 
                          reverse=True)[:3]
    
    

    template = templates_env.get_template("user-profile.html")
    return template.render(
        {
            "request": request,
            "title": Title,
            "tag" : "My Account",
            "page": "user-profile",
            "user": user,
            "joined" : joined,
            "recent_tasks": recent_tasks,
            "task_stats": task_stats,
            "data": {"user": user,
                     "task_stats": task_stats,
                    },
            "templates_env": templates_env,
            "isLogin": False
        }
    )